@@ -84,7 +84,7 @@
     } else psi.inv <- vapply(Gseq, function(g) .sim_psi_ip(P=P, psi.alpha=psi.alpha, psi.beta=psi.beta[,g]), numeric(P))
     psi.inv        <- if(uni)     t(psi.inv)    else psi.inv
     if(isTRUE(one.uni))     {
-      psi.inv[]    <- 1/switch(EXPR=uni.type, constrained=.col_vars(data), max(.col_vars(data)))
+      psi.inv[]    <- 1/switch(EXPR=uni.type, constrained=colVars(data), max(colVars(data)))
     } else  {
       tmp.psi      <- (nn[nn0] - 1L)/pmax(rowsum(data^2, z) - rowsum(data, z)^2/nn[nn0], 0L)
       tmp.psi      <- switch(EXPR=uni.type, unconstrained=t(tmp.psi), matrix(Rfast::rowMaxs(tmp.psi, value=TRUE), nrow=P, ncol=G, byrow=TRUE))
@@ -164,12 +164,12 @@
           psi.inv[,left]   <- psi.inv[,right, drop=FALSE]
           pi.prop[left]    <- pi.prop[right]
           nn[left]         <- nn[right]
-         if(mu0g)  {
-          mu.zero[,left]   <- mu.zero[,right, drop=FALSE]
-         }
-         if(psi0g) {
-          psi.beta[,left]  <- psi.beta[,right, drop=FALSE]
-         }
+          if(mu0g)  {
+           mu.zero[,left]  <- mu.zero[,right, drop=FALSE]
+          }
+          if(psi0g) {
+           psi.beta[,left] <- psi.beta[,right, drop=FALSE]
+          }
         }
       }
 
