@@ -1,7 +1,12 @@
 ## ----setup, include=FALSE-----------------------------------------------------
-knitr::opts_chunk$set(fig.width=7, fig.height = 5, fig.align = 'center', fig.show='hold',
-                      dev.args=list(type="cairo"), warning=FALSE, message=FALSE, 
-                      progress=FALSE, collapse=TRUE, comments="#>")
+knitr::opts_chunk$set(fig.width=7, fig.height = 5, fig.align = 'center', 
+                      fig.show='hold', warning=FALSE, 
+                      message=FALSE, progress=FALSE, 
+                      collapse=TRUE, comments="#>")
+
+if(isTRUE(capabilities("cairo"))) {
+  knitr::opts_chunk$set(dev.args=list(type="cairo"))
+}
 
 ## ---- eval=FALSE--------------------------------------------------------------
 #  install.packages('devtools')
